## What to do

These are broadly not useful to applied work.

These are for people developing methods. Also, for reproducibility in our paper.

We set up snakemake pipelines for comparing methods.

You will need to download the software from these packages.

- The clues folder implements https://github.com/standard-aaron/clues with trees from https://myersgroup.github.io/relate/
- The ehh folder implements iSAFE https://github.com/alek0991/iSAFE and EHH methods from selscan https://github.com/szpiech/selscan
- The imagene folder gives some scripts, an a snakemake smk file for fitting and predicting a neural network
    - https://github.com/mfumagalli/ImaGene
- The tskibd folder is an early exploratory analysis using true ibd segments https://github.com/bguo068/tskibd
    - We think this method may have an issue with simulated gene conversion tracts